<?php
/**
* Plugin Name: Magazines Filter
* Description: A filter for the ALDI magazines
* Version: 1.0
* Author: Alejandro Torres
*/

class magazinesFilter {

  private $currentID;
  private $revpp;

  public function __construct() {

    // STYLES
    add_action( 'wp_enqueue_scripts', array($this,'stylesScripts' ));

    // SHORTCODE
    add_shortcode( "magazines-filter", array($this,"print_code"));
    add_shortcode( "special-magazines", array($this,"special_magazines"));

    // AJAX Handlers
		add_action( 'wp_ajax_show_results', array( $this, 'show_results' ));
		add_action( 'wp_ajax_nopriv_show_results', array( $this, 'show_results' ));

    // Post Type Creation
		add_action( 'init', array($this, 'create_post_type' ) );

    // Adding columns to list
    add_filter('manage_revista_posts_columns', array( $this, 'ST4_columns_head'));
    add_action('manage_revista_posts_custom_column', array( $this, 'ST4_columns_content'), 10, 2);

  }

  // It creates a post type called 'Tiendas'
	public function create_post_type() {

	  register_post_type( 'revista',
	    array(
	      'labels' => array(
	        'name' => __( 'Revistas' ),
	        'singular_name' => __( 'Revista' )
	      ),
	      'public' => true,
	      'has_archive' => true,
        'supports' => array( 'title','thumbnail','excerpt' ),
        'menu_icon'   => 'dashicons-book',
	    )
	  );

	}

  public function stylesScripts() {

    // STYLES
    wp_enqueue_style( 'magazine-filter', plugin_dir_url( __FILE__ ) . "css/style.css", array(), time() );

    // SCRIPTS
    wp_enqueue_script( 'magazine-filter', plugin_dir_url( __FILE__ ) . 'js/scripts.js', array('jquery'), '', true );

    // if( get_post_type() === 'revista' ) {
    //   wp_enqueue_script( 'ofertia-script', 'https://static01.dev.ofertia.com/eviewer/latest/brochure-viewer/js/externalScripts/globalEsOfertiaScript.js', array(), '', true );
    //   wp_enqueue_script( 'ofertia-init', plugin_dir_url( __FILE__ ) . 'js/ofertia-init.js', array('ofertia-script'), '', true );
    // }

    wp_localize_script( 'magazine-filter', 'M_Filter', array(
      // URL to wp-admin/admin-ajax.php to process the request

      'ajaxurl' => admin_url( 'admin-ajax.php' ),

      // generate a nonce with a unique ID "myajax-post-comment-nonce"
      // so that you can check it later when an AJAX request is sent
      'security' => wp_create_nonce( 'magazine-filter-ajax' ),
      'postid' => get_queried_object_id()

    ));

  }

  // SHORTCODE Code
  public function print_code() {
    ?>

    <div class="up-pagination"></div>

    <!-- MAGAZINES FILTER -->
    <div class="mf-filter-wrapper">
      <ul>
        <li><?php _e('Filtrar por'); ?></li>
        <li class="r-all active"><?php _e('Todos'); ?></li>
        <?php if(get_field('ro_fe')) { ?>
        <li class="r-specials"><?php echo get_field('ro_fe_txt'); ?></li>
        <?php } ?>
        <li class="has-dropdown">

          <?php $this->getDates('F'); ?>

        </li>
        <li class="has-dropdown">

          <?php $this->getDates('Y'); ?>

        </li>

      </ul>
    </div>

    <!-- MAGAZINES AREA -->
    <div class="mf-area container">

      <?php $this->show_magazines(true,false,false,false,1,"",false); ?>

    </div>
  <?php
  }

  // Special magazines code
  public function special_magazines() {

    $storeRepo = new \WCAldi\Repositories\StoreRepo();

    if( get_field('mf_rid') ) :

      echo "<div class='row featured_magazines'>";

      // Printing the posts
      foreach( get_field('mf_rid') as $magazine ) :

        // Getting the thumbnail
        if ( has_post_thumbnail( $magazine ) ) {
          $featured_image = get_the_post_thumbnail( $magazine, 'large' );
        } else {
          $featured_image = "";
        }
        ?>

        <div class="col-md-6 col-xs-12">

          <?php echo $featured_image; ?>
          <h3><?php echo get_the_title($magazine); ?></h3>
          <h4><?php echo $this->displayDate(get_field('r_date_publish',$magazine)); ?></h4>
          <div><?php echo get_field('r_desc',$magazine); ?></div>
          <div class='r-downloads-main'>
          <?php
          if( get_field('r_cod_ofertia') == '' ) {
            if(get_field('r_cod_baleares',$magazine)) {
              
              if( $storeRepo->isBaleares() ) {
                echo "<a href='".get_permalink($magazine)."?loc=baleares'>Ver Revista</a>";
              } else {
                echo "<a href='".get_permalink($magazine)."'>Ver Revista</a>";
              }
  
            } else {
              echo "<a href='".get_permalink($magazine)."'>Ver Revista</a>";
            }
          } else {
            if(get_field('r_cod_ofertia_baleares',$magazine)) {
              
              if( $storeRepo->isBaleares() ) {
                echo "<a href='".get_permalink($magazine)."?loc=baleares'>Ver Revista</a>";
              } else {
                echo "<a href='".get_permalink($magazine)."'>Ver Revista</a>";
              }
              
            } else {
              echo "<a href='".get_permalink($magazine)."'>Ver Revista</a>";
            }
          }
          
          ?>
          </div>
        </div>

        <?php

      endforeach;
      echo "</div>";
    endif;
  }

  /********************** GETTING THE AVAILABLE DATES *************************/
  public function getDates($format) {

    $result = array();

    if($format=="Y") {
      $class="class='r-year'";
      $text=__('Por año');
      $name="Year";
    }

    if($format=="F") {
      $class="class='r-month'";
      $text=__('Por mes');
      $name="Month";
    }

    $args = array (
      'post_type' => 'revista',
      'orderby' => 'date',
      'order' => 'ASC',
      'posts_per_page' => -1
    );

    $query = new WP_Query($args);

    if($query->have_posts()) {

      while($query->have_posts()) { $query->the_post();

        $currentV = get_the_date($format);

        // Searching for previous values
        if(count($result)>0) {

          $found = false;

          foreach($result as $r) {

            if($r == $currentV) {
              $found = true;
            }

          }

          if($found == false) {
            $result[] = $currentV;
          }

        } else {
          $result[] = $currentV;
        }

      }

    }

    if($format=="F") {
      $result = $this->order_months($result);
    }

    echo '<div class="dropdown mf-dropdown">';
    echo '<button class="btn btn-default dropdown-toggle" type="button" id="dropdownMenu'.$name.'" data-toggle="dropdown" aria-haspopup="true" aria-expanded="true">
            <span class="text-drop">'.$text.'</span>
            <span class="caret"></span>
          </button>';
    echo '<ul class="dropdown-menu" aria-labelledby="dropdownMenu'.$class.'">';
    foreach($result as $r) {
        echo "<li ".$class." data-date='".$r."'><a>".$r."</a></li>";
    }
    echo '</ul>';
    echo "</div>";

  }

  // It orders the months
  function order_months($orden_mes) {

    $meses=array("enero","febrero","marzo","abril","mayo","junio","julio","agosto","septiembre","octubre","noviembre","diciembre");
    $x=0;
    while($meses[$x]!=NULL)
    {
      $y=0;
      while($orden_mes[$y]!=NULL) {
        if($orden_mes[$y]==$meses[$x]) {
          $ordenado[] = $meses[$x];
        }
        $y++;
      }
      $x++;
    }

    return $ordenado;
  }

  // It show the current and next week magazines on the top of the "all" filter
  public function featured_magazines($all,$paged) {

    $storeRepo = new \WCAldi\Repositories\StoreRepo();

    if(($all==1 && $paged==1) || ($all=="true" && $paged==1)) {

      $args = array (
            'post_status' => array( 'publish' ),
            'showposts' => 1,
            'post_type' => 'revista',
            'orderby' => 'date',
            'order' => 'DESC',
            'meta_query' => array (
              'relation' => 'AND',
              'special_clause' => array(
                'key' => 'r_especial',
                'value' => '0',
                'compare' => '='
              ),
              'apertura_clause' => array(
                'key' => 'r_apertura',
                'value' => '0',
                'compare' => '='
              )

            )
          );

      $query = new WP_Query( $args );

      if( $query->have_posts() ) :

        echo "<h3 class='featured_magazines_h3'>".__("La revista de la semana")."</h3>";
        echo "<div class='featured_magazines'>";

        // Printing the posts
        while( $query->have_posts() ) :
          $query->the_post();

          // Getting the thumbnail
          if ( has_post_thumbnail( $_post->ID ) ) {
            $featured_image = get_the_post_thumbnail( $_post->ID, 'large' );
          } else {
            $featured_image = "";
          }
          ?>

          <div class="row">

            <div class="col-md-6 col-xs-12 left">
              <?php echo $featured_image; ?>
            </div>

            <div class="col-md-6 col-xs-12">
              <div class="right">
                <h3><?php echo get_the_title(); ?></h3>
                <h4><?php echo $this->displayDate(get_field('r_date_publish',$_post->ID)); ?></h4>
                <div><?php echo get_field('r_desc',$_post->ID); ?></div>
                <div class='r-downloads-main'>
                  <?php
                  if( get_field('r_cod_ofertia') == '' ) {
                    if(get_field('r_cod_baleares',$_post->ID)) {
                      
                      if( $storeRepo->isBaleares() ) {
                        echo "<a href='".get_permalink($_post->ID)."?loc=baleares'>Ver Revista</a>";
                      } else {
                        echo "<a href='".get_permalink($_post->ID)."'>Ver Revista</a>";
                      }
          
                    } else {
                      echo "<a href='".get_permalink($_post->ID)."'>Ver Revista</a>";
                    }
                  } else {

                    if(get_field('r_cod_ofertia_baleares',$_post->ID)) {
                      
                      if( $storeRepo->isBaleares() ) {
                        echo "<a href='".get_permalink($_post->ID)."?loc=baleares'>Ver Revista</a>";
                      } else {
                        echo "<a href='".get_permalink($_post->ID)."'>Ver Revista</a>";
                      }
                      
                    } else {
                      echo "<a href='".get_permalink($_post->ID)."'>Ver Revista</a>";
                    }

                  }
                  
                  ?>
                </div>
              </div>
            </div>

          </div>

          <?php
        endwhile;
        echo "</div>";
        echo "<h3 class='featured_magazines_h3'>".__("Consulta nuestras revistas anteriores")."</h3>";
      endif;

    }


  }

  // AJAX answer to the filter buttons
  public function show_results() {

    check_ajax_referer( 'magazine-filter-ajax', 'security' );

    if($_POST['postid']) {
      $this->currentID = $_POST['postid'];
    } else {
      $this->currentID = get_queried_object_id();
    }

    $this->revpp = get_field('ro_pp',$pageid);

    if ( $_POST['month']=="" && $_POST['year']=="" ) {
      $this->show_magazines($_POST['all'],$_POST['special'],false,false,$_POST['paged'],$this->currentID);
    }

    if ( $_POST['month']!="" && $_POST['year']=="" ) {
      $this->show_magazines($_POST['all'],$_POST['special'],$_POST['month'],false,$_POST['paged'],$this->currentID);
    }

    if ( $_POST['month']=="" && $_POST['year']!="" ) {
      $this->show_magazines($_POST['all'],$_POST['special'],false,$_POST['year'],$_POST['paged'],$this->currentID);
    }

    if ( $_POST['month']!="" && $_POST['year']!="" ) {
      $this->show_magazines($_POST['all'],$_POST['special'],$_POST['month'],$_POST['year'],$_POST['paged'],$this->currentID);
    }

    die();
  }

  // Query retrieving the posts
  public function show_magazines($all,$special,$month,$year,$paged,$pageid,$ajax=true) {

    $storeRepo = new \WCAldi\Repositories\StoreRepo();

    if( $pageid ) {
      $this->currentID = $_POST['postid'];
    } else {
      $this->currentID = get_queried_object_id();
    }

    $this->revpp = get_field('ro_pp',$this->currentID);

    $this->featured_magazines($all,$paged);

    if( $all=="true" || $all==1 ) {
      if($paged==1) {
        $args = array (
          'showposts' => $this->revpp,
          'post_type' => 'revista',
          'post_parent' => 0,
          'paged' => $paged,
          'offset' => 1,
          'meta_query' => array (

            array(
              'key' => 'r_apertura',
              'value' => 0,
              'compare' => '='
            )

          )
        );
      } else {
        $args = array (
          'showposts' => $this->revpp,
          'post_type' => 'revista',
          'post_parent' => 0,
          'offset' => (($paged-1) * $this->revpp) + 1,
          'meta_query' => array (

            array(
              'key' => 'r_apertura',
              'value' => 0,
              'compare' => '='
            )

          )
        );
      }


    } else {

      $nmonth = $this->returnMonthNumber($month);

      if($special=="true"||$special==1) {

        if($month=="" && $year=="") {
          $args = array (
            'showposts' => $this->revpp,
            'post_type' => 'revista',
            'post_parent' => 0,
            'meta_key' => 'r_especial',
            'meta_value' => true,
            'paged' => $paged,
            'meta_query' => array (

              array(
                'key' => 'r_apertura',
                'value' => 0,
                'compare' => '='
              )

            )
          );
        }

        if($month!="" && $year=="") {
          $args = array (
            'showposts' => $this->revpp,
            'post_type' => 'revista',
            'post_parent' => 0,
            'monthnum' => $nmonth,
            'meta_key' => 'r_especial',
            'meta_value' => true,
            'paged' => $paged,
            'meta_query' => array (

              array(
                'key' => 'r_apertura',
                'value' => 0,
                'compare' => '='
              )

            )
          );
        }

        if($month=="" && $year!="") {
          $args = array (
            'showposts' => $this->revpp,
            'post_type' => 'revista',
            'post_parent' => 0,
            'year' => $year,
            'meta_key' => 'r_especial',
            'meta_value' => true,
            'paged' => $paged,
            'meta_query' => array (

              array(
                'key' => 'r_apertura',
                'value' => 0,
                'compare' => '='
              )

            )
          );
        }

        if($month!="" && $year!="") {
          $args = array (
            'showposts' => $this->revpp,
            'post_type' => 'revista',
            'post_parent' => 0,
            'monthnum' => $nmonth,
            'year' => $year,
            'meta_key' => 'r_especial',
            'meta_value' => true,
            'paged' => $paged,
            'meta_query' => array (

              array(
                'key' => 'r_apertura',
                'value' => 0,
                'compare' => '='
              )

            )
          );
        }
      } else {
        if($month!="" && $year=="") {
          $args = array (
            'showposts' => $this->revpp,
            'post_type' => 'revista',
            'post_parent' => 0,
            'monthnum' => $nmonth,
            'paged' => $paged,
            'meta_query' => array (

              array(
                'key' => 'r_apertura',
                'value' => 0,
                'compare' => '='
              )

            )
          );
        }

        if($month=="" && $year!="") {
          $args = array (
            'showposts' => $this->revpp,
            'post_type' => 'revista',
            'post_parent' => 0,
            'year' => $year,
            'paged' => $paged,
            'meta_query' => array (

              array(
                'key' => 'r_apertura',
                'value' => 0,
                'compare' => '='
              )

            )
          );
        }

        if($month!="" && $year!="") {
          $args = array (
            'showposts' => $this->revpp,
            'post_type' => 'revista',
            'post_parent' => 0,
            'monthnum' => $nmonth,
            'year' => $year,
            'paged' => $paged,
            'meta_query' => array (

              array(
                'key' => 'r_apertura',
                'value' => 0,
                'compare' => '='
              )

            )
          );
        }
      }


    }


    $query = new WP_Query( $args );

    if( $query->have_posts() ) :
      $i=1;
      echo "<div class='row'>";

      // Printing the posts
      while( $query->have_posts()) {
        $query->the_post();

        // Getting the thumbnail
        if ( has_post_thumbnail( $_post->ID ) ) {
          $featured_image = get_the_post_thumbnail( $_post->ID, 'medium' );
        } else {
          $featured_image = "";
        }

        echo "<div class='col-xs-12 col-md-6'>";
        echo "<div class='mf-magazine-wrapper'>";
        echo "<div class='left'>".$featured_image."</div>";
        echo "<div class='right'>";
        echo "<h4>".get_the_title()."</h4>";
        echo "<h5>".$this->displayDate(get_field('r_date_publish',$_post->ID))."</h5>";

        echo "<div class='r-text'>".get_field('r_desc',$_post->ID)."</div>";
        echo "<div class='r-downloads'>";

        if( get_field('r_cod_ofertia') == '' ) {
          if(get_field('r_cod_baleares',$_post->ID)) {
            
            if( $storeRepo->isBaleares() ) {
              echo "<a href='".get_permalink($_post->ID)."?loc=baleares'>Ver Revista</a>";
            } else {
              echo "<a href='".get_permalink($_post->ID)."'>Ver Revista</a>";
            }

          } else {
            echo "<a href='".get_permalink($_post->ID)."'>Ver Revista</a>";
          }
        } else {

          if(get_field('r_cod_ofertia_baleares',$_post->ID)) {

            if( $storeRepo->isBaleares() ) {
              echo "<a href='".get_permalink($_post->ID)."?loc=baleares'>Ver Revista</a>";
            } else {
              echo "<a href='".get_permalink($_post->ID)."'>Ver Revista</a>";
            }
            
          } else {
            echo "<a href='".get_permalink($_post->ID)."'>Ver Revista</a>";
          }

        }
        

        echo "</div>";
        echo "</div>";
        echo "<div class='clearfix'></div>";
        echo "</div>";
        echo "</div>";
        ?>

        <?php
        if($i%2==0) {
          echo "<div class='clearfix'></div>";
        }
        $i++;
      }
      echo "</div>";
      wp_reset_postdata();

      if( $all=="true" && $ajax==true ) {
        numeric_pagination($query, $paged, true, 2);
      } elseif ( $all==1 && $ajax==false ) {
        numeric_pagination($query, $paged, true, 2);
      }  else {
        numeric_pagination($query, $paged, false, 2);
      }

    else :
      echo "no"; // For Javascript error handling
    endif;
  }

  function returnMonthNumber($month) {

    switch ($month) {

      case "enero": $number=1;
        break;
      case "febrero": $number=2;
        break;
      case "marzo": $number=3;
        break;
      case "abril": $number=4;
        break;
      case "mayo": $number=5;
        break;
      case "junio": $number=6;
        break;
      case "julio": $number=7;
        break;
      case "agosto": $number=8;
        break;
      case "septiembre": $number=9;
        break;
      case "octubre": $number=10;
        break;
      case "noviembre": $number=11;
        break;
      case "diciembre": $number=12;
        break;

    }

    return $number;

  }

  public function displayDate($date) {

    $day = date('d',strtotime($date));
    $month = $this->getMonthNameSpanish(date('n',strtotime($date)));
    $year = date('Y',strtotime($date));

    return $day.' de '.$month.', '.$year;

  }

  public function getMonthNameSpanish($month) {

    switch ($month) {

      case 1: $number="enero";
        break;
      case 2: $number="febrero";
        break;
      case 3: $number="marzo";
        break;
      case 4: $number="abril";
        break;
      case 5: $number="mayo";
        break;
      case 6: $number="junio";
        break;
      case 7: $number="julio";
        break;
      case 8: $number="agosto";
        break;
      case 9: $number="septiembre";
        break;
      case 10: $number="octubre";
        break;
      case 11: $number="noviembre";
        break;
      case 12: $number="diciembre";
        break;

    }

    return $number;

  }

  //******************** ADDING COLUMNS TO THE LIST OF THE MAGAZINES IN THE BACKEND ***********
  // GET FIELD
  public function get_special_list($post_ID) {
    if (get_field('r_especial',$post_ID)) {
      return "<div style='width:25px;height:25px;background-color:#8bc34a;border-radius:5px;'></div>";
    } else {
      return "<div style='width:25px;height:25px;background-color:#ff9191;border-radius:5px;'></div>";
    }
  }

  public function get_apertura_list($post_ID) {
    if (get_field('r_apertura',$post_ID)) {
      return "<div style='width:25px;height:25px;background-color:#8bc34a;border-radius:5px;'></div>";
    } else {
      return "<div style='width:25px;height:25px;background-color:#ff9191;border-radius:5px;'></div>";
    }
  }
  // ADD NEW COLUMN
  public function ST4_columns_head($defaults) {

      $defaults['r_special'] = 'Especial';
      $defaults['r_apertura'] = 'Apertura';
      return $defaults;

  }

  // SHOW THE CONTENT
  public function ST4_columns_content($column_name, $post_ID) {
      if ($column_name == 'r_special') {
          $special = $this->get_special_list($post_ID);
          if ($special) {
              echo $special;
          }
      }
      if ($column_name == 'r_apertura') {
          $apertura = $this->get_apertura_list($post_ID);
          if ($apertura) {
              echo $apertura;
          }
      }
  }

}

define( 'PLUGIN_DIR_2', dirname(__FILE__).'/' );
require_once( PLUGIN_DIR_2 . '/acf-revistas.php');

$mfp = new magazinesFilter();
